@@ -21,6 +21,7 @@ Settings::Settings()
     _scrollingEnabled = false;
 
     _backgroundFilename = 0; // Will be set later if not in config file
+    _backgroundMode = Stretched;
 
     _headerLeftFilename = strdup("/usr/share/telescope/header-left.png");
     _headerRightFilename = strdup("/usr/share/telescope/header-right.png");
@@ -69,14 +70,13 @@ Settings::Settings()
                 if (strstr(line, prefix1) == line)
                 {
                     char tmp[1024];
+                    int len = strcspn( &line[strlen(prefix1)], "\n");
                     strncpy(
                         tmp,
                         &line[strlen(prefix1)],
-                        strcspn(
-                            &line[strlen(prefix1)],
-                            "\n"
-                        )
+                        len
                     );
+                    tmp[len] = '\0';
                     _backgroundFilename = urldecode(tmp);
                 }
                 else if (strstr(line, prefix3) == line)
@@ -88,6 +88,17 @@ Settings::Settings()
                         _backgroundFilename = strndup(&line[strlen(prefix3)], valuelen);
                     }
                 }
+                else if (strstr(line, "Mode=") == line)
+                {
+                    if (strcmp(&line[5], "Stretched\n") == 0)
+                        _backgroundMode = Stretched;
+                    else if (strcmp(&line[5], "Centered\n") == 0)
+                        _backgroundMode = Centered;
+                    else if (strcmp(&line[5], "Scaled\n") == 0)
+                        _backgroundMode = Scaled;
+                    else if (strcmp(&line[5], "Cropped\n") == 0)
+                        _backgroundMode = Cropped;
+                }
             }
 
             fclose(homeBgFile);
@@ -130,7 +141,7 @@ char* Settings::urldecode(const char *url)
     if (strstr(url, "file://") == url)
         url += 7;
 
-    char *result = (char*)malloc(strlen(url));
+    char *result = (char*)malloc(strlen(url) + 1);
     char *r = result;
 
     while (*url)
@@ -147,6 +158,9 @@ char* Settings::urldecode(const char *url)
             *r++ = *url++;
     }
 
+    *r = '\0';
+
+
     return result;
 }
 
@@ -208,6 +222,17 @@ void Settings::parseOpt(const char *key, const char *value)
 
         printf("Background: '%s'\n", _backgroundFilename);
     }
+    else if (strcmp(key, "background.mode") == 0)
+    {
+        if (strcmp(value, "stretched") == 0)
+            _backgroundMode = Stretched;
+        else if (strcmp(value, "centered") == 0)
+            _backgroundMode = Centered;
+        else if (strcmp(value, "scaled") == 0)
+            _backgroundMode = Scaled;
+        else if (strcmp(value, "cropped") == 0)
+            _backgroundMode = Cropped;
+    }
     else if (strcmp(key, "header.left.filename") == 0)
     {
         free(_headerLeftFilename);
