@@ -3,11 +3,21 @@
 
 class Settings
 {
+    public:
+        enum BackgroundMode
+        {
+            Stretched,
+            Centered,
+            Scaled,
+            Cropped
+        };
+
     private:
         static Settings *_instance;
 
         bool _scrollingEnabled;
         char *_backgroundFilename;
+        BackgroundMode _backgroundMode;
 
         char *_headerLeftFilename;
         char *_headerRightFilename;
@@ -38,7 +48,9 @@ class Settings
         static Settings* instance();
 
         bool scrollingEnabled() { return _scrollingEnabled; }
+
         const char* backgroundFilename() { return _backgroundFilename; }
+        BackgroundMode backgroundMode() { return _backgroundMode; }
 
         const char* headerLeftFilename() { return _headerLeftFilename; }
         const char* headerRightFilename() { return _headerRightFilename; }
